@@ -30,10 +30,12 @@ def create_fts_parser(server, db_name, schema_name, fts_parser_name):
                                        server['sslmode'])
         pg_cursor = connection.cursor()
 
-        query = "DROP TEXT SEARCH PARSER IF EXISTS " + schema_name + "." + fts_parser_name
+        query = "DROP TEXT SEARCH PARSER IF EXISTS " + schema_name + "." + \
+                fts_parser_name
         pg_cursor.execute(query)
 
-        query = "CREATE TEXT SEARCH PARSER " + schema_name + "." + fts_parser_name + \
+        query = "CREATE TEXT SEARCH PARSER " + schema_name + "." + \
+                fts_parser_name + \
                 "(START=prsd_start, GETTOKEN=prsd_nexttoken, " \
                 "END=prsd_end, LEXTYPES=dispell_init)"
 
