@@ -2,8 +2,11 @@
 define('pgadmin.node.function', [
   'sources/gettext', 'sources/url_for', 'jquery', 'underscore', 'backbone',
   'sources/pgadmin', 'pgadmin.browser', 'pgadmin.backform',
-  'pgadmin.browser.collection', 'pgadmin.browser.server.privilege',
-], function(gettext, url_for, $, _, Backbone, pgAdmin, pgBrowser, Backform) {
+  'pgadmin.node.schema.dir/child', 'pgadmin.browser.collection',
+  'pgadmin.browser.server.privilege',
+], function(
+  gettext, url_for, $, _, Backbone, pgAdmin, pgBrowser, Backform, schemaChild
+) {
 
   if (!pgBrowser.Nodes['coll-function']) {
     pgBrowser.Nodes['coll-function'] =
@@ -83,7 +86,8 @@ define('pgadmin.node.function', [
   });
 
   if (!pgBrowser.Nodes['function']) {
-    pgBrowser.Nodes['function'] = pgBrowser.Node.extend({
+
+    pgBrowser.Nodes['function'] = schemaChild.SchemaChildNode.extend({
       type: 'function',
       sqlAlterHelp: 'sql-alterfunction.html',
       sqlCreateHelp: 'sql-createfunction.html',
@@ -96,7 +100,6 @@ define('pgadmin.node.function', [
         return treeInformation.server.server_type !== 'gpdb';
       },
       hasScriptTypes: ['create', 'select'],
-      parent_type: ['schema', 'catalog'],
       Init: function() {
         /* Avoid mulitple registration of menus */
         if (this.initialized)
@@ -126,8 +129,6 @@ define('pgadmin.node.function', [
         ]);
 
       },
-      canDrop: pgBrowser.Nodes['schema'].canChildDrop,
-      canDropCascade: pgBrowser.Nodes['schema'].canChildDrop,
       model: pgBrowser.Node.Model.extend({
         initialize: function(attrs, args) {
           var isNew = (_.size(attrs) === 0);
@@ -254,6 +255,7 @@ define('pgadmin.node.function', [
         },{
           id: 'provolatile', label: gettext('Volatility'), cell: 'string',
           control: 'node-ajax-options', type: 'text', group: gettext('Options'),
+          deps: ['lanname'],
           options:[
             {'label': 'VOLATILE', 'value': 'v'},
             {'label': 'STABLE', 'value': 's'},
@@ -266,6 +268,7 @@ define('pgadmin.node.function', [
         },{
           id: 'proisstrict', label: gettext('Strict?'), type: 'switch',
           group: gettext('Options'), disabled: 'isDisabled',
+          deps: ['lanname'],
           options: {
             'onText': gettext('Yes'), 'offText': gettext('No'),
             'onColor': 'success', 'offColor': 'primary',
@@ -282,6 +285,7 @@ define('pgadmin.node.function', [
         },{
           id: 'proparallel', label: gettext('Parallel'), cell: 'string',
           control: 'node-ajax-options', type: 'text', group: gettext('Options'),
+          deps: ['lanname'],
           options:[
             {'label': 'UNSAFE', 'value': 'u'},
             {'label': 'RESTRICTED', 'value': 'r'},
@@ -290,7 +294,7 @@ define('pgadmin.node.function', [
           select2: {allowClear: false},
         },{
           id: 'procost', label: gettext('Estimated cost'), group: gettext('Options'),
-          cell:'string', type: 'text', disabled: 'isDisabled',
+          cell:'string', type: 'text', disabled: 'isDisabled', deps: ['lanname'],
         },{
           id: 'prorows', label: gettext('Estimated rows'), type: 'text',
           deps: ['proretset'], visible: 'isVisible', disabled: 'isDisabled',
@@ -298,7 +302,7 @@ define('pgadmin.node.function', [
         },{
           id: 'proleakproof', label: gettext('Leak proof?'),
           group: gettext('Options'), cell:'boolean', type: 'switch', min_version: 90200,
-          disabled: 'isDisabled',
+          disabled: 'isDisabled', deps: ['lanname'],
         },{
           id: 'proacl', label: gettext('Privileges'), type: 'text',
           mode: ['properties'], group: gettext('Security'),
@@ -438,34 +442,6 @@ define('pgadmin.node.function', [
           return true;
         },
       }),
-      canCreate: function(itemData, item, data) {
-        //If check is false then , we will allow create menu
-        if (data && data.check == false)
-          return true;
-
-        var t = pgBrowser.tree, i = item, d = itemData;
-        // To iterate over tree to check parent node
-        while (i) {
-          // If it is schema then allow user to create Function
-          if (_.indexOf(['schema'], d._type) > -1)
-            return true;
-
-          if ('coll-function' == d._type) {
-            //Check if we are not child of catalog
-            var prev_i = t.hasParent(i) ? t.parent(i) : null,
-              prev_d = prev_i ? t.itemData(prev_i) : null;
-            if( prev_d._type == 'catalog') {
-              return false;
-            } else {
-              return true;
-            }
-          }
-          i = t.hasParent(i) ? t.parent(i) : null;
-          d = i ? t.itemData(i) : null;
-        }
-        // by default we do not want to allow create menu
-        return true;
-      },
     });
 
   }
