@@ -4,24 +4,14 @@
 {% set is_columns = [] %}
 {% if data %}
 {% if query_for == 'sql_panel' and func_def is defined %}
-CREATE OR REPLACE  PROCEDURE {{func_def}}
+CREATE OR REPLACE PROCEDURE {{func_def}}
 {% else %}
 CREATE OR REPLACE PROCEDURE {{ conn|qtIdent(data.pronamespace, data.name) }}{% if data.arguments is defined %}
 ({% for p in data.arguments %}{% if p.argmode %}{{p.argmode}} {% endif %}{% if p.argname %}{{ conn|qtIdent(p.argname)}} {% endif %}{% if p.argtype %}{{ conn|qtTypeIdent(p.argtype) }}{% endif %}{% if p.argdefval %} DEFAULT {{p.argdefval}}{% endif %}
-{% if not loop.last %}, {% endif %}
+ {% if not loop.last %}, {% endif %}
 {% endfor -%}
-){% endif %}
-
 {% endif %}
-    {{ data.provolatile }} {% if data.proleakproof %}LEAKPROOF {% endif %}
-{% if data.proisstrict %}STRICT {% endif %}
-{% if data.prosecdef %}SECURITY DEFINER {% endif %}{% if data.procost %}
-
-    COST {{data.procost}}{% endif %}{% if data.prorows and (data.prorows | int) > 0 %}
-
-    ROWS {{data.prorows}}{% endif -%}{% if data.variables %}{% for v in data.variables %}
-
-    SET {{ conn|qtIdent(v.name) }}={{ v.value|qtLiteral }}{% endfor -%}
+)
 {% endif %}
 
 AS {{ data.prosrc }};
@@ -48,4 +38,5 @@ COMMENT ON PROCEDURE {{ conn|qtIdent(data.pronamespace, data.name) }}
 {% endfor %}
 {% endif -%}
 
+
 {% endif %}
