@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -14,13 +14,14 @@ import re
 
 import pgadmin.browser.server_groups.servers.databases as database
 from flask import render_template, request, jsonify, url_for
-from flask_babel import gettext
+from flask_babelex import gettext
 from pgadmin.browser.server_groups.servers.databases.schemas.utils \
     import SchemaChildModule, DataTypeReader, VacuumSettings
 from pgadmin.browser.server_groups.servers.utils import parse_priv_to_db
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
     make_response as ajax_response, gone
 from .utils import BaseTableView
+from pgadmin.utils.preferences import Preferences
 
 
 class TableModule(SchemaChildModule):
@@ -78,7 +79,8 @@ class TableModule(SchemaChildModule):
 
         scripts.append({
             'name': 'pgadmin.browser.table.partition.utils',
-            'path': url_for('browser.index') + 'table/static/js/partition.utils',
+            'path': url_for('browser.index') +
+                    'table/static/js/partition.utils',
             'when': 'database', 'is_template': False
         })
 
@@ -241,13 +243,15 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
         'select_sql': [{'get': 'select_sql'}],
         'insert_sql': [{'get': 'insert_sql'}],
         'update_sql': [{'get': 'update_sql'}],
-        'delete_sql': [{'get': 'delete_sql'}]
+        'delete_sql': [{'get': 'delete_sql'}],
+        'count_rows': [{'get': 'count_rows'}]
     })
 
     @BaseTableView.check_precondition
     def list(self, gid, sid, did, scid):
         """
-        This function is used to list all the table nodes within that collection.
+        This function is used to list all the table nodes within that
+        collection.
 
         Args:
             gid: Server group ID
@@ -275,7 +279,8 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
     @BaseTableView.check_precondition
     def node(self, gid, sid, did, scid, tid):
         """
-        This function is used to list all the table nodes within that collection.
+        This function is used to list all the table nodes within that
+        collection.
 
         Args:
             gid: Server group ID
@@ -298,15 +303,18 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
         if len(rset['rows']) == 0:
                 return gone(gettext("Could not find the table."))
 
+        table_information = rset['rows'][0]
+        icon = self.get_icon_css_class(table_information)
+
         res = self.blueprint.generate_browser_node(
-                rset['rows'][0]['oid'],
-                scid,
-                rset['rows'][0]['name'],
-                icon="icon-partition" if 'is_partitioned' in rset['rows'][0] and rset['rows'][0]['is_partitioned'] else "icon-table",
-                tigger_count=rset['rows'][0]['triggercount'],
-                has_enable_triggers=rset['rows'][0]['has_enable_triggers'],
-                is_partitioned=rset['rows'][0]['is_partitioned'] if 'is_partitioned' in rset['rows'][0] else False
-            )
+            table_information['oid'],
+            scid,
+            table_information['name'],
+            icon=icon,
+            tigger_count=table_information['triggercount'],
+            has_enable_triggers=table_information['has_enable_triggers'],
+            is_partitioned=self.is_table_partitioned(table_information)
+        )
 
         return make_json_response(
             data=res,
@@ -316,7 +324,8 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
     @BaseTableView.check_precondition
     def nodes(self, gid, sid, did, scid):
         """
-        This function is used to list all the table nodes within that collection.
+        This function is used to list all the table nodes within that
+        collection.
 
         Args:
             gid: Server group ID
@@ -337,15 +346,18 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
             return internal_server_error(errormsg=rset)
 
         for row in rset['rows']:
+            icon = self.get_icon_css_class(row)
+
             res.append(
                 self.blueprint.generate_browser_node(
                     row['oid'],
                     scid,
                     row['name'],
-                    icon="icon-partition" if 'is_partitioned' in row and row['is_partitioned'] else "icon-table",
+                    icon=icon,
                     tigger_count=row['triggercount'],
                     has_enable_triggers=row['has_enable_triggers'],
-                    is_partitioned=row['is_partitioned'] if 'is_partitioned' in row else False
+                    is_partitioned=self.is_table_partitioned(row),
+                    rows_cnt=0
                 ))
 
         return make_json_response(
@@ -564,8 +576,42 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
         if len(res['rows']) == 0:
                 return gone(gettext("The specified table could not be found."))
 
+        # We will check the threshold set by user before executing
+        # the query because that can cause performance issues
+        # with large result set
+        pref = Preferences.module('browser')
+        table_row_count_pref = pref.preference('table_row_count_threshold')
+        table_row_count_threshold = table_row_count_pref.get()
+        estimated_row_count = int(res['rows'][0].get('reltuples', 0))
+
+        # If estimated rows are greater than threshold then
+        if estimated_row_count and \
+                estimated_row_count > table_row_count_threshold:
+            res['rows'][0]['rows_cnt'] = str(table_row_count_threshold) + '+'
+
+        # If estimated rows is lower than threshold then calculate the count
+        elif estimated_row_count and \
+                table_row_count_threshold >= estimated_row_count:
+            SQL = render_template(
+                "/".join(
+                    [self.table_template_path, 'get_table_row_count.sql']
+                ), data=res['rows'][0]
+            )
+
+            status, count = self.conn.execute_scalar(SQL)
+
+            if not status:
+                return internal_server_error(errormsg=count)
+
+            res['rows'][0]['rows_cnt'] = count
+
+        # If estimated_row_count is zero then set the row count with same
+        elif not estimated_row_count:
+            res['rows'][0]['rows_cnt'] = estimated_row_count
+
         return super(TableView, self).properties(
-            gid, sid, did, scid, tid, res)
+            gid, sid, did, scid, tid, res
+        )
 
     @BaseTableView.check_precondition
     def types(self, gid, sid, did, scid, tid=None, clid=None):
@@ -581,7 +627,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
             show_system_objects=self.blueprint.show_system_objects
         )
 
-        status, types = self.get_types(self.conn, condition, True)
+        status, types = self.get_types(self.conn, condition, True, sid)
 
         if not status:
             return internal_server_error(errormsg=types)
@@ -662,19 +708,23 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
                 return internal_server_error(errormsg=res)
             for row in rset['rows']:
                 # Get columns for all 'OF TYPES'.
-                SQL = render_template("/".join([self.table_template_path,
-                                                'get_columns_for_table.sql']),
-                                      tid=row['oid'])
+                SQL = render_template(
+                    "/".join(
+                        [self.table_template_path,
+                         'get_columns_for_table.sql']
+                    ), tid=row['oid']
+                )
 
                 status, type_cols = self.conn.execute_dict(SQL)
                 if not status:
                     return internal_server_error(errormsg=type_cols)
 
-                res.append(
-                    {'label': row['typname'], 'value': row['typname'],
-                     'tid': row['oid'], 'oftype_columns': type_cols['rows']
-                     }
-                )
+                res.append({
+                    'label': row['typname'],
+                    'value': row['typname'],
+                    'tid': row['oid'],
+                    'oftype_columns': type_cols['rows']
+                })
             return make_json_response(
                 data=res,
                 status=200
@@ -696,6 +746,7 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
                 "/".join([self.table_template_path, 'get_inherits.sql']),
                 show_system_objects=self.blueprint.show_system_objects,
                 tid=tid,
+                scid=scid,
                 server_type=self.manager.server_type
             )
             status, rset = self.conn.execute_2darray(SQL)
@@ -752,8 +803,8 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
     def get_relations(self, gid, sid, did, scid, tid=None):
         """
         Returns:
-            This function will return list of tables available for like/relation
-            combobox while creating new table
+            This function will return list of tables available for
+            like/relation combobox while creating new table
         """
         res = [{'label': '', 'value': ''}]
         try:
@@ -767,7 +818,10 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
                 return internal_server_error(errormsg=res)
             for row in rset['rows']:
                 res.append(
-                    {'label': row['like_relation'], 'value': row['like_relation']}
+                    {
+                        'label': row['like_relation'],
+                        'value': row['like_relation']
+                    }
                 )
             return make_json_response(
                 data=res,
@@ -798,11 +852,14 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
 
                     for c in final_columns:
                         if 'attacl' in c:
-                            c['attacl'] = parse_priv_to_db(c['attacl'], self.column_acl)
+                            c['attacl'] = parse_priv_to_db(
+                                c['attacl'], self.column_acl
+                            )
 
                         if 'cltype' in c:
                             # check type for '[]' in it
-                            c['cltype'], c['hasSqrBracket'] = self._cltype_formatter(c['cltype'])
+                            c['cltype'], c['hasSqrBracket'] = \
+                                self._cltype_formatter(c['cltype'])
 
                         c = TableView.convert_length_precision_to_string(c)
 
@@ -820,11 +877,14 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
             # to include in our create definition, Let's format them
             for c in final_columns:
                 if 'attacl' in c:
-                    c['attacl'] = parse_priv_to_db(c['attacl'], self.column_acl)
+                    c['attacl'] = parse_priv_to_db(
+                        c['attacl'], self.column_acl
+                    )
 
                 if 'cltype' in c:
                     # check type for '[]' in it
-                    c['cltype'], c['hasSqrBracket'] = self._cltype_formatter(c['cltype'])
+                    c['cltype'], c['hasSqrBracket'] = \
+                        self._cltype_formatter(c['cltype'])
 
                 c = TableView.convert_length_precision_to_string(c)
 
@@ -900,13 +960,11 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
 
         try:
             partitions_sql = ''
-            partitioned = False
-            if 'is_partitioned' in data and data['is_partitioned']:
+            if self.is_table_partitioned(data):
                 data['relkind'] = 'p'
                 # create partition scheme
                 data['partition_scheme'] = self.get_partition_scheme(data)
                 partitions_sql = self.get_partitions_sql(data)
-                partitioned = True
 
             SQL = render_template(
                 "/".join([self.table_template_path, 'create.sql']),
@@ -953,8 +1011,8 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
                     tid,
                     scid,
                     data['name'],
-                    icon="icon-partition" if partitioned else "icon-table",
-                    is_partitioned=partitioned
+                    icon=self.get_icon_css_class(data),
+                    is_partitioned=self.is_table_partitioned(data)
                 )
             )
         except Exception as e:
@@ -1059,7 +1117,9 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
             if not status:
                 return internal_server_error(errormsg=res)
 
-            return super(TableView, self).truncate(gid, sid, did, scid, tid, res)
+            return super(TableView, self).truncate(
+                gid, sid, did, scid, tid, res
+            )
 
         except Exception as e:
             return internal_server_error(errormsg=str(e))
@@ -1426,4 +1486,39 @@ class TableView(BaseTableView, DataTypeReader, VacuumSettings):
         """
         return BaseTableView.get_table_statistics(self, scid, tid)
 
+    @BaseTableView.check_precondition
+    def count_rows(self, gid, sid, did, scid, tid):
+        """
+        Count the rows of a table.
+        Args:
+            gid: Server Group Id
+            sid: Server Id
+            did: Database Id
+            scid: Schema Id
+            tid: Table Id
+
+        Returns the total rows of a table.
+        """
+        data = {}
+        data['schema'], data['name'] = \
+            super(TableView, self).get_schema_and_table_name(tid)
+
+        SQL = render_template(
+            "/".join(
+                [self.table_template_path, 'get_table_row_count.sql']
+            ), data=data
+        )
+
+        status, count = self.conn.execute_scalar(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=count)
+
+        return make_json_response(
+            status=200,
+            info=gettext("Table rows counted"),
+            data={'total_rows': count}
+        )
+
+
 TableView.register_node_view(blueprint)
