@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -13,7 +13,7 @@ import re
 import simplejson as json
 import pgadmin.browser.server_groups.servers.databases.schemas as schema
 from flask import render_template, request
-from flask_babel import gettext
+from flask_babelex import gettext
 from pgadmin.browser.server_groups.servers.databases.schemas.utils \
     import DataTypeReader, VacuumSettings
 from pgadmin.utils.ajax import internal_server_error, \
@@ -26,6 +26,25 @@ from config import PG_DEFAULT_DRIVER
 from pgadmin.browser.utils import PGChildModule
 
 
+def backend_supported(module, manager, **kwargs):
+    if 'tid' in kwargs and CollectionNodeModule.BackendSupported(
+            module, manager, **kwargs):
+        conn = manager.connection(did=kwargs['did'])
+
+        template_path = 'partition/sql/{0}/#{0}#{1}#'.format(
+            manager.server_type, manager.version
+        )
+        SQL = render_template("/".join(
+            [template_path, 'backend_support.sql']), tid=kwargs['tid'])
+        status, res = conn.execute_scalar(SQL)
+
+        # check if any errors
+        if not status:
+            return internal_server_error(errormsg=res)
+
+        return res
+
+
 class PartitionsModule(CollectionNodeModule):
     """
      class PartitionsModule(CollectionNodeModule)
@@ -62,6 +81,8 @@ class PartitionsModule(CollectionNodeModule):
         super(PartitionsModule, self).__init__(*args, **kwargs)
         self.min_ver = 100000
         self.max_ver = None
+        self.min_ppasver = 100000
+        self.max_ppasver = None
 
     def get_nodes(self, gid, sid, did, scid, **kwargs):
         """
@@ -88,21 +109,7 @@ class PartitionsModule(CollectionNodeModule):
         """
         Load this module if it is a partition table
         """
-        if manager.server_type == 'gpdb':
-            return False
-        if 'tid' in kwargs and CollectionNodeModule.BackendSupported(self, manager, **kwargs):
-            conn = manager.connection(did=kwargs['did'])
-
-            template_path = 'partition/sql/#{0}#'.format(manager.version)
-            SQL = render_template("/".join(
-                [template_path, 'backend_support.sql']), tid=kwargs['tid'])
-            status, res = conn.execute_scalar(SQL)
-
-            # check if any errors
-            if not status:
-                return internal_server_error(errormsg=res)
-
-            return res
+        return backend_supported(self, manager, **kwargs)
 
     def register(self, app, options, first_registration=False):
         """
@@ -113,7 +120,9 @@ class PartitionsModule(CollectionNodeModule):
         if first_registration:
             self.submodules = list(app.find_submodules(self.import_name))
 
-        super(CollectionNodeModule, self).register(app, options, first_registration)
+        super(CollectionNodeModule, self).register(
+            app, options, first_registration
+        )
 
         for module in self.submodules:
             if first_registration:
@@ -231,10 +240,6 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
             else:
                 nodes.extend(module.get_nodes(**kwargs))
 
-        # Explicitly include 'partition' module as we had excluded it during
-        # registration.
-        nodes.extend(self.blueprint.get_nodes(**kwargs))
-
         # Return sorted nodes based on label
         return make_json_response(
             data=sorted(
@@ -289,9 +294,9 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
             JSON of available table nodes
         """
         SQL = render_template(
-                "/".join([self.partition_template_path, 'nodes.sql']),
-                scid=scid, tid=tid
-                )
+            "/".join([self.partition_template_path, 'nodes.sql']),
+            scid=scid, tid=tid
+        )
         status, rset = self.conn.execute_2darray(SQL)
         if not status:
             return internal_server_error(errormsg=rset)
@@ -301,7 +306,7 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
                 row['oid'],
                 tid,
                 row['name'],
-                icon="icon-partition",
+                icon=self.get_icon_css_class({}),
                 tigger_count=row['triggercount'],
                 has_enable_triggers=row['has_enable_triggers'],
                 is_partitioned=row['is_partitioned'],
@@ -318,7 +323,7 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
 
             return make_json_response(
                 data=browser_node(rset['rows'][0]), status=200
-                )
+            )
 
         res = []
         for row in rset['rows']:
@@ -461,9 +466,10 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
             temp_data['schema'] = partition_schema
             temp_data['name'] = partition_name
 
-            SQL = render_template("/".join(
-                            [self.partition_template_path, 'detach.sql']),
-                            data=temp_data, conn=self.conn)
+            SQL = render_template(
+                "/".join([self.partition_template_path, 'detach.sql']),
+                data=temp_data, conn=self.conn
+            )
 
             status, res = self.conn.execute_scalar(SQL)
             if not status:
@@ -577,7 +583,9 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
             if not status:
                 return internal_server_error(errormsg=res)
 
-            return super(PartitionsView, self).truncate(gid, sid, did, scid, ptid, res)
+            return super(PartitionsView, self).truncate(
+                gid, sid, did, scid, ptid, res
+            )
 
         except Exception as e:
             return internal_server_error(errormsg=str(e))
@@ -598,7 +606,7 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
         try:
             SQL = render_template(
                 "/".join([self.partition_template_path, 'properties.sql']),
-                did=did, scid=scid, tid=tid,ptid=ptid,
+                did=did, scid=scid, tid=tid, ptid=ptid,
                 datlastsysoid=self.datlastsysoid
             )
             status, res = self.conn.execute_dict(SQL)
