@@ -1,13 +1,16 @@
 define('pgadmin.node.table', [
+  'pgadmin.tables.js/enable_disable_triggers',
   'sources/gettext', 'sources/url_for', 'jquery', 'underscore',
   'underscore.string', 'sources/pgadmin', 'pgadmin.browser',
   'pgadmin.alertifyjs', 'pgadmin.backform', 'pgadmin.backgrid',
   'pgadmin.tables.js/show_advanced_tab',
-  'pgadmin.browser.collection', 'pgadmin.node.column',
-  'pgadmin.node.constraints', 'pgadmin.browser.table.partition.utils',
+  'pgadmin.node.schema.dir/child', 'pgadmin.browser.collection',
+  'pgadmin.node.column', 'pgadmin.node.constraints',
+  'pgadmin.browser.table.partition.utils',
 ], function(
+  tableFunctions,
   gettext, url_for, $, _, S, pgAdmin, pgBrowser, Alertify, Backform, Backgrid,
-  ShowAdvancedTab
+  ShowAdvancedTab, SchemaChild
 ) {
 
   if (!pgBrowser.Nodes['coll-table']) {
@@ -25,8 +28,7 @@ define('pgadmin.node.table', [
   }
 
   if (!pgBrowser.Nodes['table']) {
-    pgBrowser.Nodes['table'] = pgBrowser.Node.extend({
-      getTreeNodeHierarchy: pgBrowser.tableChildTreeNodeHierarchy,
+    pgBrowser.Nodes['table'] = SchemaChild.SchemaChildNode.extend({
       type: 'table',
       label: gettext('Table'),
       collection_type: 'coll-table',
@@ -39,7 +41,6 @@ define('pgadmin.node.table', [
       sqlAlterHelp: 'sql-altertable.html',
       sqlCreateHelp: 'sql-createtable.html',
       dialogHelp: url_for('help.static', {'filename': 'table_dialog.html'}),
-      parent_type: ['schema', 'catalog'],
       hasScriptTypes: ['create', 'select', 'insert', 'update', 'delete'],
       height: '95%',
       width: '85%',
@@ -113,58 +114,24 @@ define('pgadmin.node.table', [
           this.handle_cache, this
         );
       },
-      canDrop: pgBrowser.Nodes['schema'].canChildDrop,
-      canDropCascade: pgBrowser.Nodes['schema'].canChildDrop,
       callbacks: {
         /* Enable trigger(s) on table */
         enable_triggers_on_table: function(args) {
-          var params = {'enable': true };
-          this.callbacks.set_triggers.apply(this, [args, params]);
+          tableFunctions.enableTriggers(
+            pgBrowser.treeMenu,
+            Alertify,
+            this.generate_url.bind(this),
+            args
+          );
         },
         /* Disable trigger(s) on table */
         disable_triggers_on_table: function(args) {
-          var params = {'enable': false };
-          this.callbacks.set_triggers.apply(this, [args, params]);
-        },
-        set_triggers: function(args, params) {
-          // This function will send request to enable or
-          // disable triggers on table level
-          var input = args || {},
-            obj = this,
-            t = pgBrowser.tree,
-            i = input.item || t.selected(),
-            d = i && i.length == 1 ? t.itemData(i) : undefined;
-          if (!d)
-            return false;
-
-          $.ajax({
-            url: obj.generate_url(i, 'set_trigger' , d, true),
-            type:'PUT',
-            data: params,
-            dataType: 'json',
-            success: function(res) {
-              if (res.success == 1) {
-                Alertify.success(res.info);
-                t.unload(i);
-                t.setInode(i);
-                t.deselect(i);
-                setTimeout(function() {
-                  t.select(i);
-                }, 10);
-              }
-            },
-            error: function(xhr) {
-              try {
-                var err = $.parseJSON(xhr.responseText);
-                if (err.success == 0) {
-                  Alertify.error(err.errormsg);
-                }
-              } catch (e) {
-                console.warn(e.stack || e);
-              }
-              t.unload(i);
-            },
-          });
+          tableFunctions.disableTriggers(
+            pgBrowser.treeMenu,
+            Alertify,
+            this.generate_url.bind(this),
+            args
+          );
         },
         /* Truncate table */
         truncate_table: function(args) {
@@ -197,32 +164,25 @@ define('pgadmin.node.table', [
                   type:'PUT',
                   data: params,
                   dataType: 'json',
-                  success: function(res) {
-                    if (res.success == 1) {
-                      Alertify.success(res.info);
-                      t.removeIcon(i);
-                      data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
-                      t.addIcon(i, {icon: data.icon});
-                      t.unload(i);
-                      t.setInode(i);
-                      t.deselect(i);
-                      // Fetch updated data from server
-                      setTimeout(function() {
-                        t.select(i);
-                      }, 10);
-                    }
-                  },
-                  error: function(xhr) {
-                    try {
-                      var err = $.parseJSON(xhr.responseText);
-                      if (err.success == 0) {
-                        Alertify.error(err.errormsg);
-                      }
-                    } catch (e) {
-                      console.warn(e.stack || e);
-                    }
+                })
+                .done(function(res) {
+                  if (res.success == 1) {
+                    Alertify.success(res.info);
+                    t.removeIcon(i);
+                    data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
+                    t.addIcon(i, {icon: data.icon});
                     t.unload(i);
-                  },
+                    t.setInode(i);
+                    t.deselect(i);
+                    // Fetch updated data from server
+                    setTimeout(function() {
+                      t.select(i);
+                    }, 10);
+                  }
+                })
+                .fail(function(xhr, status, error) {
+                  Alertify.pgRespErrorNotify(xhr, error);
+                  t.unload(i);
                 });
               }
             }, function() {}
@@ -247,32 +207,25 @@ define('pgadmin.node.table', [
                 $.ajax({
                   url: obj.generate_url(i, 'reset' , d, true),
                   type:'DELETE',
-                  success: function(res) {
-                    if (res.success == 1) {
-                      Alertify.success(res.info);
-                      t.removeIcon(i);
-                      data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
-                      t.addIcon(i, {icon: data.icon});
-                      t.unload(i);
-                      t.setInode(i);
-                      t.deselect(i);
-                      // Fetch updated data from server
-                      setTimeout(function() {
-                        t.select(i);
-                      }, 10);
-                    }
-                  },
-                  error: function(xhr) {
-                    try {
-                      var err = $.parseJSON(xhr.responseText);
-                      if (err.success == 0) {
-                        Alertify.error(err.errormsg);
-                      }
-                    } catch (e) {
-                      console.warn(e.stack || e);
-                    }
+                })
+                .done(function(res) {
+                  if (res.success == 1) {
+                    Alertify.success(res.info);
+                    t.removeIcon(i);
+                    data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
+                    t.addIcon(i, {icon: data.icon});
                     t.unload(i);
-                  },
+                    t.setInode(i);
+                    t.deselect(i);
+                    // Fetch updated data from server
+                    setTimeout(function() {
+                      t.select(i);
+                    }, 10);
+                  }
+                })
+                .fail(function(xhr, status, error) {
+                  Alertify.pgRespErrorNotify(xhr, error);
+                  t.unload(i);
                 });
               }
             },
@@ -292,27 +245,20 @@ define('pgadmin.node.table', [
           $.ajax({
             url: obj.generate_url(i, 'count_rows' , d, true),
             type:'GET',
-            success: function(res) {
-              Alertify.success(res.info);
-              d.rows_cnt = res.data.total_rows;
-              t.unload(i);
-              t.setInode(i);
-              t.deselect(i);
-              setTimeout(function() {
-                t.select(i);
-              }, 10);
-            },
-            error: function(xhr) {
-              try {
-                var err = $.parseJSON(xhr.responseText);
-                if (err.success == 0) {
-                  Alertify.error(err.errormsg);
-                }
-              } catch (e) {
-                console.warn(e.stack || e);
-              }
-              t.unload(i);
-            },
+          })
+          .done(function(res) {
+            Alertify.success(res.info);
+            d.rows_cnt = res.data.total_rows;
+            t.unload(i);
+            t.setInode(i);
+            t.deselect(i);
+            setTimeout(function() {
+              t.select(i);
+            }, 10);
+          })
+          .fail(function(xhr, status, error) {
+            Alertify.pgRespErrorNotify(xhr, error);
+            t.unload(i);
           });
         },
       },
@@ -647,7 +593,9 @@ define('pgadmin.node.table', [
             control: 'unique-col-collection',
             columns : ['name', 'columns'],
             canAdd: function(m) {
-              if (m.get('is_partitioned')) {
+              if (m.get('is_partitioned') && !_.isUndefined(m.top.node_info) && !_.isUndefined(m.top.node_info.server)
+              && !_.isUndefined(m.top.node_info.server.version) &&
+                m.top.node_info.server.version < 110000) {
                 setTimeout(function() {
                   var coll = m.get('primary_key');
                   coll.remove(coll.filter(function() { return true; }));
@@ -674,7 +622,9 @@ define('pgadmin.node.table', [
             canEdit: true, canDelete: true, deps:['is_partitioned'],
             control: 'unique-col-collection',
             canAdd: function(m) {
-              if (m.get('is_partitioned')) {
+              if (m.get('is_partitioned') && !_.isUndefined(m.top.node_info) && !_.isUndefined(m.top.node_info.server)
+              && !_.isUndefined(m.top.node_info.server.version) &&
+                m.top.node_info.server.version < 110000) {
                 setTimeout(function() {
                   var coll = m.get('foreign_key');
                   coll.remove(coll.filter(function() { return true; }));
@@ -710,7 +660,8 @@ define('pgadmin.node.table', [
             control: 'unique-col-collection',
             columns : ['name', 'columns'],
             canAdd: function(m) {
-              if (m.get('is_partitioned')) {
+              if (m.get('is_partitioned') && !_.isUndefined(m.node_info) && !_.isUndefined(m.node_info.server)
+              && !_.isUndefined(m.node_info.server.version) && m.node_info.server.version < 110000) {
                 setTimeout(function() {
                   var coll = m.get('unique_constraint');
                   coll.remove(coll.filter(function() { return true; }));
@@ -888,11 +839,22 @@ define('pgadmin.node.table', [
           id: 'partition_type', label:gettext('Partition Type'),
           editable: false, type: 'select2', select2: {allowClear: false},
           group: 'partition', deps: ['is_partitioned'],
-          options:[{
-            label: gettext('Range'), value: 'range',
-          },{
-            label: gettext('List'), value: 'list',
-          }],
+          options: function() {
+            var options = [{
+              label: gettext('Range'), value: 'range',
+            },{
+              label: gettext('List'), value: 'list',
+            }];
+
+            if(!_.isUndefined(this.node_info) && !_.isUndefined(this.node_info.server)
+              && !_.isUndefined(this.node_info.server.version) &&
+                this.node_info.server.version >= 110000) {
+              options.push({
+                label: gettext('Hash'), value: 'hash',
+              });
+            }
+            return options;
+          },
           mode:['create'],
           visible: function(m) {
             if(!_.isUndefined(m.node_info) && !_.isUndefined(m.node_info.server)
@@ -1017,7 +979,7 @@ define('pgadmin.node.table', [
           canEdit: false, canDelete: true,
           customDeleteTitle: gettext('Detach Partition'),
           customDeleteMsg: gettext('Are you sure you wish to detach this partition?'),
-          columns:['is_attach', 'partition_name', 'values_from', 'values_to', 'values_in'],
+          columns:['is_attach', 'partition_name', 'values_from', 'values_to', 'values_in', 'values_modulus', 'values_remainder'],
           control: Backform.SubNodeCollectionControl.extend({
             row: Backgrid.PartitionRow,
             initialize: function() {
@@ -1037,20 +999,19 @@ define('pgadmin.node.table', [
 
                   type: 'GET',
                   async: false,
-                  success: function(res) {
-                    if (res.success == 1) {
-                      self.model.table_options = res.data;
-                    }
-                    else {
-                      Alertify.alert(
-                        gettext('Error fetching tables to be attached'), res.data.result
-                      );
-                    }
-                  },
-                  error: function(e) {
-                    var errmsg = $.parseJSON(e.responseText);
-                    Alertify.alert(gettext('Error fetching tables to be attached'), errmsg.errormsg);
-                  },
+                })
+                .done(function(res) {
+                  if (res.success == 1) {
+                    self.model.table_options = res.data;
+                  }
+                  else {
+                    Alertify.alert(
+                      gettext('Error fetching tables to be attached'), res.data.result
+                    );
+                  }
+                })
+                .fail(function(xhr, status, error) {
+                  Alertify.pgRespErrorNotify(xhr, error);
                 });
               }
             },
@@ -1095,6 +1056,8 @@ define('pgadmin.node.table', [
             '</li><li> ',
             gettext('In: Enabled for list partition. Values must be comma(,) separated and quoted with single quote.'),
             '</li></ul></li></ul>',
+            gettext('Modulus/Remainder: Enabled for hash partition.'),
+            '</li></ul></li></ul>',
           ].join(''),
           visible: function(m) {
             if(!_.isUndefined(m.node_info) && !_.isUndefined(m.node_info.server)
@@ -1316,67 +1279,27 @@ define('pgadmin.node.table', [
             async: false,
             url: full_url,
             data: arg,
-            success: function(res) {
-              data = cache_node.cache(url, node_info, cache_level, res.data);
-            },
-            error: function() {
-              m.trigger('pgadmin:view:fetch:error', m, self.field);
-            },
+          })
+          .done(function(res) {
+            data = cache_node.cache(url, node_info, cache_level, res.data);
+          })
+          .fail(function() {
+            m.trigger('pgadmin:view:fetch:error', m, self.field);
           });
           m.trigger('pgadmin:view:fetched', m, self.field);
           data = (data && data.data) || [];
           return data;
         },
       }),
-      canCreate: function(itemData, item, data) {
-        //If check is false then , we will allow create menu
-        if (data && data.check == false)
-          return true;
-
-        var t = pgBrowser.tree, i = item, d = itemData;
-        // To iterate over tree to check parent node
-        while (i) {
-          // If it is schema then allow user to create table
-          if (_.indexOf(['schema'], d._type) > -1)
-            return true;
-
-          if ('coll-table' == d._type) {
-            //Check if we are not child of catalog
-            var prev_i = t.hasParent(i) ? t.parent(i) : null,
-              prev_d = prev_i ? t.itemData(prev_i) : null;
-            if( prev_d._type == 'catalog') {
-              return false;
-            } else {
-              return true;
-            }
-          }
-          i = t.hasParent(i) ? t.parent(i) : null;
-          d = i ? t.itemData(i) : null;
-        }
-        // by default we do not want to allow create menu
-        return true;
-      },
       // Check to whether table has disable trigger(s)
       canCreate_with_trigger_enable: function(itemData, item, data) {
-        if(this.canCreate.apply(this, [itemData, item, data])) {
-          // We are here means we can create menu, now let's check condition
-          if(itemData.tigger_count > 0) {
-            return true;
-          } else {
-            return false;
-          }
-        }
+        return itemData.tigger_count > 0 &&
+          this.canCreate.apply(this, [itemData, item, data]);
       },
       // Check to whether table has enable trigger(s)
       canCreate_with_trigger_disable: function(itemData, item, data) {
-        if(this.canCreate.apply(this, [itemData, item, data])) {
-          // We are here means we can create menu, now let's check condition
-          if(itemData.tigger_count > 0 && itemData.has_enable_triggers > 0) {
-            return true;
-          } else {
-            return false;
-          }
-        }
+        return itemData.tigger_count > 0 && itemData.has_enable_triggers > 0 &&
+          this.canCreate.apply(this, [itemData, item, data]);
       },
       onTableUpdated: function(_node, _oldNodeData, _newNodeData) {
         var key, childIDs;
