@@ -14,6 +14,9 @@ from functools import wraps
 import simplejson as json
 from flask import render_template, jsonify, request
 from flask_babelex import gettext
+
+from pgadmin.browser.server_groups.servers.databases.schemas\
+    .tables.base_partition_table import BasePartitionTable
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
     make_response as ajax_response
 from pgadmin.browser.server_groups.servers.databases.schemas.utils \
@@ -22,11 +25,12 @@ from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
     parse_priv_to_db
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils import IS_PY2
+from pgadmin.utils.compile_template_name import compile_template_path
 from pgadmin.utils.driver import get_driver
 from config import PG_DEFAULT_DRIVER
 
 
-class BaseTableView(PGChildNodeView):
+class BaseTableView(PGChildNodeView, BasePartitionTable):
     """
     This class is base class for tables and partitioned tables.
 
@@ -106,38 +110,37 @@ class BaseTableView(PGChildNodeView):
             ver = self.manager.version
             server_type = self.manager.server_type
             # Set the template path for the SQL scripts
-            self.table_template_path = 'table/sql/' + (
-                '#{0}#{1}#'.format(server_type, ver)
-                if server_type == 'gpdb' else
-                '#{0}#'.format(ver)
-            )
-            self.data_type_template_path = 'datatype/sql/' + (
-                '#{0}#{1}#'.format(server_type, ver) if
-                server_type == 'gpdb' else'#{0}#'.format(ver)
-            )
+            self.table_template_path = compile_template_path('table/sql',
+                                                             server_type, ver)
+            self.data_type_template_path = compile_template_path(
+                'datatype/sql',
+                server_type, ver)
             self.partition_template_path = \
                 'partition/sql/{0}/#{0}#{1}#'.format(server_type, ver)
 
             # Template for Column ,check constraint and exclusion
             # constraint node
             self.column_template_path = 'column/sql/#{0}#'.format(ver)
-            self.check_constraint_template_path = \
-                'check_constraint/sql/#{0}#'.format(ver)
-            self.exclusion_constraint_template_path = \
-                'exclusion_constraint/sql/#{0}#'.format(ver)
+            self.check_constraint_template_path = compile_template_path(
+                'check_constraint/sql', server_type, ver)
+            self.exclusion_constraint_template_path = compile_template_path(
+                'exclusion_constraint/sql', server_type, ver)
 
             # Template for PK & Unique constraint node
-            self.index_constraint_template_path = 'index_constraint/sql'
+            self.index_constraint_template_path = 'index_constraint/sql/#{0}#'\
+                .format(ver)
 
             # Template for foreign key constraint node
-            self.foreign_key_template_path = \
-                'foreign_key/sql/#{0}#'.format(ver)
+            self.foreign_key_template_path = compile_template_path(
+                'foreign_key/sql', server_type, ver)
 
             # Template for index node
-            self.index_template_path = 'index/sql/#{0}#'.format(ver)
+            self.index_template_path = compile_template_path(
+                'index/sql', server_type, ver)
 
             # Template for trigger node
-            self.trigger_template_path = 'trigger/sql/#{0}#'.format(ver)
+            self.trigger_template_path = compile_template_path(
+                'trigger/sql', server_type, ver)
 
             # Template for rules node
             self.rules_template_path = 'rules/sql'
@@ -366,7 +369,7 @@ class BaseTableView(PGChildNodeView):
                     "/".join([self.index_constraint_template_path,
                               'get_constraint_cols.sql']),
                     cid=row['oid'],
-                    colcnt=row['indnatts'])
+                    colcnt=row['col_count'])
                 status, res = self.conn.execute_dict(sql)
 
                 if not status:
@@ -378,6 +381,19 @@ class BaseTableView(PGChildNodeView):
 
                 result['columns'] = columns
 
+                # INCLUDE clause in index is supported from PG-11+
+                if self.manager.version >= 110000:
+                    sql = render_template(
+                        "/".join([self.index_constraint_template_path,
+                                  'get_constraint_include.sql']),
+                        cid=row['oid'])
+                    status, res = self.conn.execute_dict(sql)
+
+                    if not status:
+                        return internal_server_error(errormsg=res)
+
+                    result['include'] = [col['colname'] for col in res['rows']]
+
                 # If not exists then create list and/or append into
                 # existing list [ Adding into main data dict]
                 data.setdefault(index_constraints[ctype], []).append(result)
@@ -511,7 +527,7 @@ class BaseTableView(PGChildNodeView):
                 [self.exclusion_constraint_template_path,
                  'get_constraint_cols.sql']),
                 cid=ex['oid'],
-                colcnt=ex['indnatts'])
+                colcnt=ex['col_count'])
 
             status, res = self.conn.execute_dict(sql)
 
@@ -536,6 +552,20 @@ class BaseTableView(PGChildNodeView):
                                 })
 
             ex['columns'] = columns
+
+            # INCLUDE clause in index is supported from PG-11+
+            if self.manager.version >= 110000:
+                sql = render_template(
+                    "/".join([self.exclusion_constraint_template_path,
+                              'get_constraint_include.sql']),
+                    cid=ex['oid'])
+                status, res = self.conn.execute_dict(sql)
+
+                if not status:
+                    return internal_server_error(errormsg=res)
+
+                ex['include'] = [col['colname'] for col in res['rows']]
+
             # If not exists then create list and/or append into
             # existing list [ Adding into main data dict]
             data.setdefault('exclude_constraint', []).append(ex)
@@ -844,6 +874,7 @@ class BaseTableView(PGChildNodeView):
         # Table & Schema declaration so that we can use them in child nodes
         schema = data['schema']
         table = data['name']
+        is_partitioned = 'is_partitioned' in data and data['is_partitioned']
 
         data = self._formatter(did, scid, tid, data)
 
@@ -960,6 +991,18 @@ class BaseTableView(PGChildNodeView):
             # Push as string
             data['cols'] = ', '.join(cols)
 
+            if self.manager.version >= 110000:
+                SQL = render_template(
+                    "/".join([self.index_template_path,
+                              'include_details.sql']),
+                    idx=row['oid'])
+                status, res = self.conn.execute_dict(SQL)
+
+                if not status:
+                    return internal_server_error(errormsg=res)
+
+                data['include'] = [col['colname'] for col in res['rows']]
+
             sql_header = u"\n-- Index: {0}\n\n-- ".format(data['name'])
 
             sql_header += render_template("/".join([self.index_template_path,
@@ -1001,6 +1044,8 @@ class BaseTableView(PGChildNodeView):
             if not status:
                 return internal_server_error(errormsg=res)
 
+            if len(res['rows']) == 0:
+                continue
             data = dict(res['rows'][0])
             # Adding parent into data dict, will be using it while creating sql
             data['schema'] = schema
@@ -1095,7 +1140,7 @@ class BaseTableView(PGChildNodeView):
         # 5) Reverse engineered sql for PARTITIONS
         ##########################################
         """
-        if 'is_partitioned' in data and data['is_partitioned']:
+        if is_partitioned:
             SQL = render_template("/".join([self.partition_template_path,
                                             'nodes.sql']),
                                   scid=scid, tid=tid)
@@ -1167,6 +1212,9 @@ class BaseTableView(PGChildNodeView):
         elif 'partition_type' in data \
                 and data['partition_type'] == 'list':
             partition_scheme = 'LIST ('
+        elif 'partition_type' in data \
+                and data['partition_type'] == 'hash':
+            partition_scheme = 'HASH ('
 
         for row in data['partition_keys']:
             if row['key_type'] == 'column':
@@ -2068,13 +2116,7 @@ class BaseTableView(PGChildNodeView):
                     partitions_oid['created'] = created
                     partitions_oid['attached'] = attached
 
-            if self.node_type == 'partition':
-                icon = "icon-partition"
-            elif 'is_partitioned' in res['rows'][0] and \
-                    res['rows'][0]['is_partitioned']:
-                icon = "icon-partition"
-            else:
-                icon = "icon-table"
+            icon = self.get_icon_css_class(res['rows'][0])
 
             if 'relkind' in res['rows'][0] and \
                     res['rows'][0]['relkind'] == 'p':
@@ -2167,7 +2209,7 @@ class BaseTableView(PGChildNodeView):
                         'values_from': range_from,
                         'values_to': range_to
                     })
-                else:
+                elif data['partition_type'] == 'list':
                     range_part = \
                         row['partition_value'].split('FOR VALUES IN (')[1]
 
@@ -2177,6 +2219,20 @@ class BaseTableView(PGChildNodeView):
                         'partition_name': partition_name,
                         'values_in': range_in
                     })
+                else:
+                    range_part = row['partition_value'].split(
+                        'FOR VALUES WITH (')[1].split(",")
+                    range_modulus = range_part[0].strip().strip(
+                        "modulus").strip()
+                    range_remainder = range_part[1].strip().\
+                        strip(" remainder").strip(")").strip()
+
+                    partitions.append({
+                        'oid': row['oid'],
+                        'partition_name': partition_name,
+                        'values_modulus': range_modulus,
+                        'values_remainder': range_remainder
+                    })
 
             data['partitions'] = partitions
 
@@ -2218,10 +2274,26 @@ class BaseTableView(PGChildNodeView):
 
                 part_data['partition_value'] = 'FOR VALUES FROM (' + from_str \
                                                + ') TO (' + to_str + ')'
-            else:
+
+            elif partitions['partition_type'] == 'list':
                 range_in = row['values_in'].split(',')
                 in_str = ', '.join("{0}".format(item) for item in range_in)
-                part_data['partition_value'] = 'FOR VALUES IN (' + in_str + ')'
+                part_data['partition_value'] = 'FOR VALUES IN (' + in_str\
+                                               + ')'
+
+            else:
+                range_modulus = row['values_modulus'].split(',')
+                range_remainder = row['values_remainder'].split(',')
+
+                modulus_str = ', '.join("{0}".format(item) for item in
+                                        range_modulus)
+                remainder_str = ', '.join("{0}".format(item) for item in
+                                          range_remainder)
+
+                part_data['partition_value'] = 'FOR VALUES WITH (MODULUS '\
+                                               + modulus_str \
+                                               + ', REMAINDER ' +\
+                                               remainder_str + ')'
 
             if 'is_attach' in row and row['is_attach']:
                 partition_sql = render_template(
@@ -2391,7 +2463,7 @@ class BaseTableView(PGChildNodeView):
             sql = render_template(
                 "/".join([self.foreign_key_template_path, 'get_cols.sql']),
                 cid=costrnt['oid'],
-                colcnt=costrnt['indnatts'])
+                colcnt=costrnt['col_count'])
             status, rest = self.conn.execute_dict(sql)
 
             if not status:
