@@ -21,9 +21,10 @@ define([
       setup: function() {
         return {
           options: {
-            //disable both padding and overflow control.
+            // Disable both padding and overflow control.
             padding: !1,
             overflow: !1,
+            closable: true,
           },
         };
       },
@@ -95,7 +96,7 @@ define([
       if (contentType) {
         try {
           if (contentType.indexOf('application/json') == 0) {
-            var resp = $.parseJSON(msg);
+            var resp = JSON.parse(msg);
 
             if (resp.result != null && (!resp.errormsg || resp.errormsg == '') &&
               onJSONResult && typeof(onJSONResult) == 'function') {
@@ -127,13 +128,54 @@ define([
             return;
           }
         } catch (e) {
-          alertify.alert().show().set('message', e.message).set('title', 'Error');
+          alertify.alert().show().set('message', e.message).set(
+            'title', 'Error'
+          ).set('closable', true);
         }
       }
     }
     alertify.alert().show().set(
       'message', msg.replace(new RegExp(/\r?\n/, 'g'), '<br />')
-    ).set('title', promptmsg);
+    ).set('title', promptmsg).set('closable', true);
+  };
+
+  alertify.pgRespErrorNotify = (xhr, error, prefixMsg='') => {
+    var contentType = xhr.getResponseHeader('Content-Type');
+    try {
+      if (xhr.status === 0) {
+        error = gettext('Connection to the server has been lost.');
+      } else {
+        if(contentType){
+          if(contentType.indexOf('application/json') >= 0) {
+            var resp = JSON.parse(xhr.responseText);
+            error = _.escape(resp.result) || _.escape(resp.errormsg) || gettext('Unknown error');
+          }
+        }
+        if (contentType.indexOf('text/html') >= 0) {
+          var alertMessage = '\
+                <div class="media font-red-3 text-14">\
+                  <div class="media-body media-middle">\
+                    <div class="alert-text">' + gettext('INTERNAL SERVER ERROR') + '</div><br/>\
+                    <div class="alert-text">' + gettext('Click for details.') + '</div>\
+                  </div>\
+                </div>';
+
+          alertify.notify(
+            alertMessage, 'error', 0, () => {
+              alertify.pgIframeDialog()
+                .show()
+                .set({frameless: false})
+                .set('pg_msg', xhr.responseText);
+            }
+          );
+          return;
+        }
+      }
+    }
+    catch(e){
+      error = e.message;
+    }
+    alertify.error(prefixMsg +' '+error);
   };
 
   var alertifyDialogResized = function(stop) {
@@ -211,7 +253,7 @@ define([
     var contentType = xhr.getResponseHeader('Content-Type'),
       jsonResp = contentType &&
       contentType.indexOf('application/json') == 0 &&
-      $.parseJSON(xhr.responseText);
+      JSON.parse(xhr.responseText);
 
     if (
       jsonResp && (
@@ -295,25 +337,25 @@ define([
           null, 'connect', args.info.server, true, args.info
         ),
         dataType: 'json',
-        success: function(res) {
-          if (res.success && 'connected' in res.data) {
-            if (res.data.connected) {
-              // Server is connected, but - the connection with the
-              // particular database has been lost.
-              pgBrowser.Events.trigger(
-                'pgadmin:database:connection:lost', args.item, jsonResp
-              );
-              return;
-            }
+      })
+      .done(function(res) {
+        if (res.success && 'connected' in res.data) {
+          if (res.data.connected) {
+            // Server is connected, but - the connection with the
+            // particular database has been lost.
+            pgBrowser.Events.trigger(
+              'pgadmin:database:connection:lost', args.item, jsonResp
+            );
+            return;
           }
+        }
 
-          // Serever was not connected, we should first try to connect
-          // the server.
-          reconnectServer();
-        },
-        error: function() {
-          reconnectServer();
-        },
+        // Serever was not connected, we should first try to connect
+        // the server.
+        reconnectServer();
+      })
+      .fail(function() {
+        reconnectServer();
       });
       return true;
     }
