@@ -2,7 +2,7 @@
 //
 // pgAdmin 4 - PostgreSQL Tools
 //
-// Copyright (C) 2013 - 2017, The pgAdmin Development Team
+// Copyright (C) 2013 - 2018, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
 //////////////////////////////////////////////////////////////
@@ -92,18 +92,21 @@ export default class QueryHistory extends React.Component {
   render() {
     return (
       <SplitPane defaultSize='50%' split='vertical' pane1Style={queryEntryListDivStyle}
-                 pane2Style={queryDetailDivStyle}>
+        pane2Style={queryDetailDivStyle}>
         <QueryHistoryEntries historyEntries={this.state.history}
-                             selectedEntry={this.state.selectedEntry}
-                             onSelectEntry={this.selectHistoryEntry}
+          selectedEntry={this.state.selectedEntry}
+          onSelectEntry={this.selectHistoryEntry}
+        />
+        <QueryHistoryDetail historyEntry={this.state.currentHistoryDetail}
+            sqlEditorPref={this.props.sqlEditorPref}
         />
-        <QueryHistoryDetail historyEntry={this.state.currentHistoryDetail}/>
       </SplitPane>);
   }
 }
 
 QueryHistory.propTypes = {
   historyCollection: Shapes.historyCollectionClass.isRequired,
+  sqlEditorPref: Shapes.sqlEditorPrefObj,
 };
 
 export {
