@@ -2,7 +2,7 @@
 //
 // pgAdmin 4 - PostgreSQL Tools
 //
-// Copyright (C) 2013 - 2017, The pgAdmin Development Team
+// Copyright (C) 2013 - 2018, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
 //////////////////////////////////////////////////////////////////////////
@@ -25,7 +25,13 @@ let historyCollectionClass =
     onChange: PropTypes.func.isRequired,
   });
 
+let sqlEditorPrefObj =
+  PropTypes.shape({
+    sql_font_size: PropTypes.string.isRequired,
+  });
+
 export default {
   historyDetail,
   historyCollectionClass,
+  sqlEditorPrefObj,
 };
