@@ -1,10 +1,14 @@
 define('pgadmin.datagrid', [
   'sources/gettext', 'sources/url_for', 'jquery', 'underscore',
   'pgadmin.alertifyjs', 'sources/pgadmin', 'bundled_codemirror',
-  'sources/sqleditor_utils', 'backbone', 'wcdocker',
+  'sources/sqleditor_utils', 'backbone',
+  'tools/datagrid/static/js/show_data',
+  'tools/datagrid/static/js/get_panel_title',
+  'tools/datagrid/static/js/show_query_tool',
+  'wcdocker',
 ], function(
   gettext, url_for, $, _, alertify, pgAdmin, codemirror, sqlEditorUtils,
-  Backbone
+  Backbone, showData, panelTitle, showQueryTool
 ) {
   // Some scripts do export their object in the window only.
   // Generally the one, which do no have AMD support.
@@ -25,6 +29,23 @@ define('pgadmin.datagrid', [
         this.initialized = true;
         this.title_index = 1;
 
+
+        let self = this;
+        /* Cache may take time to load for the first time
+         * Keep trying till available
+         */
+        let cacheIntervalId = setInterval(function() {
+          if(pgBrowser.preference_version() > 0) {
+            self.preferences = pgBrowser.get_preferences_for_module('sqleditor');
+            clearInterval(cacheIntervalId);
+          }
+        },0);
+
+        pgBrowser.onPreferencesChange('sqleditor', function() {
+          self.preferences = pgBrowser.get_preferences_for_module('sqleditor');
+        });
+
+
         this.spinner_el = '<div class="wcLoadingContainer">'+
               '<div class="wcLoadingBackground"></div>'+
                 '<div class="wcLoadingIconContainer">'+
@@ -161,55 +182,7 @@ define('pgadmin.datagrid', [
 
       // This is a callback function to show data when user click on menu item.
       show_data_grid: function(data, i) {
-        var self = this,
-          d = pgAdmin.Browser.tree.itemData(i);
-        if (d === undefined) {
-          alertify.alert(
-            gettext('Data Grid Error'),
-            gettext('No object selected.')
-          );
-          return;
-        }
-
-        // Get the parent data from the tree node hierarchy.
-        var node = pgBrowser.Nodes[d._type],
-          parentData = node.getTreeNodeHierarchy(i);
-
-        // If server, database or schema is undefined then return from the function.
-        if (parentData.server === undefined || parentData.database === undefined) {
-          return;
-        }
-        // If schema, view, catalog object all are undefined then return from the function.
-        if (parentData.schema === undefined && parentData.view === undefined &&
-             parentData.catalog === undefined) {
-          return;
-        }
-
-        var nsp_name = '';
-
-        if (parentData.schema != undefined) {
-          nsp_name = parentData.schema.label;
-        }
-        else if (parentData.view != undefined) {
-          nsp_name = parentData.view.label;
-        }
-        else if (parentData.catalog != undefined) {
-          nsp_name = parentData.catalog.label;
-        }
-        var url_params = {
-          'cmd_type': data.mnuid,
-          'obj_type': d._type,
-          'sgid': parentData.server_group._id,
-          'sid': parentData.server._id,
-          'did': parentData.database._id,
-          'obj_id': d._id,
-        };
-
-        var baseUrl = url_for('datagrid.initialize_datagrid', url_params);
-        var grid_title = parentData.server.label + ' - ' + parentData.database.label + ' - '
-                        + nsp_name + '.' + d.label;
-
-        self.create_transaction(baseUrl, null, 'false', parentData.server.server_type, '', grid_title, '');
+        showData.showDataGrid(this, pgBrowser, alertify, data, i);
       },
 
       // This is a callback function to show filtered data when user click on menu item.
@@ -286,10 +259,12 @@ define('pgadmin.datagrid', [
                 return {
                   buttons:[{
                     text: gettext('OK'),
+                    key: 13,
                     className: 'btn btn-primary',
                   },
                   {
                     text: gettext('Cancel'),
+                    key: 27,
                     className: 'btn btn-danger',
                   },
                   ],
@@ -306,7 +281,7 @@ define('pgadmin.datagrid', [
                 alertify.pgDialogBuild.apply(this);
               },
               prepare:function() {
-                var self = this,
+                var that = this,
                   $content = $(this.message),
                   $sql_filter = $content.find('#sql_filter');
 
@@ -321,17 +296,21 @@ define('pgadmin.datagrid', [
                   lineNumbers: true,
                   mode: 'text/x-pgsql',
                   extraKeys: pgBrowser.editor_shortcut_keys,
-                  indentWithTabs: pgAdmin.Browser.editor_options.indent_with_tabs,
-                  indentUnit: pgAdmin.Browser.editor_options.tabSize,
-                  tabSize: pgBrowser.editor_options.tabSize,
-                  lineWrapping: pgAdmin.Browser.editor_options.wrapCode,
-                  autoCloseBrackets: pgAdmin.Browser.editor_options.insert_pair_brackets,
-                  matchBrackets: pgAdmin.Browser.editor_options.brace_matching,
+                  indentWithTabs: !self.preferences.use_spaces,
+                  indentUnit: self.preferences.tab_size,
+                  tabSize: self.preferences.tab_size,
+                  lineWrapping: self.preferences.wrap_code,
+                  autoCloseBrackets: self.preferences.insert_pair_brackets,
+                  matchBrackets: self.preferences.brace_matching,
                 });
 
+                let sql_font_size = sqlEditorUtils.calcFontSize(self.preferences.sql_font_size);
+                $(this.filter_obj.getWrapperElement()).css('font-size', sql_font_size);
+
                 setTimeout(function() {
                   // Set focus on editor
-                  self.filter_obj.focus();
+                  that.filter_obj.refresh();
+                  that.filter_obj.focus();
                 }, 500);
               },
 
@@ -348,24 +327,24 @@ define('pgadmin.datagrid', [
                     async: false,
                     contentType: 'application/json',
                     data: JSON.stringify(sql),
-                    success: function(res) {
-                      if (res.data.status) {
-                        // Initialize the data grid.
-                        self.create_transaction(that.baseUrl, null, 'false', parentData.server.server_type, '', grid_title, sql, false);
-                      }
-                      else {
-                        alertify.alert(
-                          gettext('Validation Error'),
-                            res.data.result
-                        );
-                      }
-                    },
-                    error: function(e) {
+                  })
+                  .done(function(res) {
+                    if (res.data.status) {
+                      // Initialize the data grid.
+                      self.create_transaction(that.baseUrl, null, 'false', parentData.server.server_type, '', grid_title, sql, false);
+                    }
+                    else {
                       alertify.alert(
                         gettext('Validation Error'),
-                        e
+                          res.data.result
                       );
-                    },
+                    }
+                  })
+                  .fail(function(e) {
+                    alertify.alert(
+                      gettext('Validation Error'),
+                      e
+                    );
                   });
                 }
               },
@@ -382,63 +361,12 @@ define('pgadmin.datagrid', [
       },
 
       get_panel_title: function() {
-        // Get the parent data from the tree node hierarchy.
-        var tree = pgAdmin.Browser.tree,
-          selected_item = tree.selected(),
-          item_data = tree.itemData(selected_item);
-
-        var node = pgBrowser.Nodes[item_data._type],
-          parentData = node.getTreeNodeHierarchy(selected_item);
-
-        // If server, database is undefined then return from the function.
-        if (parentData.server === undefined) {
-          return;
-        }
-        // If Database is not available then use default db
-        var db_label = parentData.database ? parentData.database.label
-                                           : parentData.server.db;
-
-        var grid_title = db_label + ' on ' + parentData.server.user.name + '@' +
-                parentData.server.label;
-        return grid_title;
+        return panelTitle.getPanelTitle(pgBrowser);
       },
       // This is a callback function to show query tool when user click on menu item.
-      show_query_tool: function(url, i, panel_title) {
-        var sURL = url || '',
-          d = pgAdmin.Browser.tree.itemData(i);
-
-        panel_title = panel_title || '';
-        if (d === undefined) {
-          alertify.alert(
-            gettext('Query Tool Error'),
-            gettext('No object selected.')
-          );
-          return;
-        }
-
-        // Get the parent data from the tree node hierarchy.
-        var node = pgBrowser.Nodes[d._type],
-          parentData = node.getTreeNodeHierarchy(i);
-
-        // If server, database is undefined then return from the function.
-        if (parentData.server === undefined) {
-          return;
-        }
-
-        var url_params = {
-            'sgid': parentData.server_group._id,
-            'sid': parentData.server._id,
-          },
-          url_endpoint = 'datagrid.initialize_query_tool';
-        // If database not present then use Maintenance database
-        // We will handle this at server side
-        if (parentData.database) {
-          url_params['did'] = parentData.database._id;
-          url_endpoint = 'datagrid.initialize_query_tool_with_did';
-        }
-        var baseUrl = url_for(url_endpoint, url_params);
-
-        this.create_transaction(baseUrl, null, 'true', parentData.server.server_type, sURL, panel_title, '', false);
+      show_query_tool: function(url, aciTreeIdentifier, panelTitle) {
+        showQueryTool.showQueryTool(this, pgBrowser, alertify, url,
+          aciTreeIdentifier, panelTitle);
       },
       create_transaction: function(baseUrl, target, is_query_tool, server_type, sURL, panel_title, sql_filter, recreate) {
         var self = this;
@@ -452,35 +380,35 @@ define('pgadmin.datagrid', [
           dataType: 'json',
           data: JSON.stringify(sql_filter),
           contentType: 'application/json',
-          success: function(res) {
-            res.data.is_query_tool = is_query_tool;
-            res.data.server_type = server_type;
-            res.data.sURL = sURL;
-            res.data.panel_title = panel_title;
-            target.trigger('pgadmin-datagrid:transaction:created', res.data);
-          },
-          error: function(xhr) {
-            if (target !== self) {
-              if(xhr.status == 503 && xhr.responseJSON.info != undefined &&
-                  xhr.responseJSON.info == 'CONNECTION_LOST') {
-                setTimeout(function() {
-                  target.handle_connection_lost(true, xhr);
-                });
-                return;
-              }
+        })
+        .done(function(res) {
+          res.data.is_query_tool = is_query_tool;
+          res.data.server_type = server_type;
+          res.data.sURL = sURL;
+          res.data.panel_title = panel_title;
+          target.trigger('pgadmin-datagrid:transaction:created', res.data);
+        })
+        .fail(function(xhr) {
+          if (target !== self) {
+            if(xhr.status == 503 && xhr.responseJSON.info != undefined &&
+                xhr.responseJSON.info == 'CONNECTION_LOST') {
+              setTimeout(function() {
+                target.handle_connection_lost(true, xhr);
+              });
+              return;
             }
+          }
 
-            try {
-              var err = $.parseJSON(xhr.responseText);
-              alertify.alert(gettext('Query Tool Initialize Error'),
-                err.errormsg
-              );
-            } catch (e) {
-              alertify.alert(
-                e.statusText, gettext('Query Tool Initialize Error')
-              );
-            }
-          },
+          try {
+            var err = JSON.parse(xhr.responseText);
+            alertify.alert(gettext('Query Tool Initialize Error'),
+              err.errormsg
+            );
+          } catch (e) {
+            alertify.alert(
+              e.statusText, gettext('Query Tool Initialize Error')
+            );
+          }
         });
       },
       launch_grid: function(trans_obj) {
@@ -508,13 +436,20 @@ define('pgadmin.datagrid', [
           }
         }
 
-        if (trans_obj.newBrowserTab) {
+        if (self.preferences.new_browser_tab) {
           var newWin = window.open(baseUrl, '_blank');
 
           // add a load listener to the window so that the title gets changed on page load
           newWin.addEventListener('load', function() {
             newWin.document.title = panel_title;
+
+            /* Set the initial version of pref cache the new window is having
+             * This will be used by the poller to compare with window openers
+             * pref cache version
+             */
+            //newWin.pgAdmin.Browser.preference_version(pgBrowser.preference_version());
           });
+
         } else {
           /* On successfully initialization find the dashboard panel,
            * create new panel and add it to the dashboard panel.
