@@ -12,6 +12,7 @@ import codecs
 import os
 import pickle
 import random
+import sys
 
 import simplejson as json
 from flask import Response, url_for, render_template, session, request, \
@@ -34,7 +35,7 @@ from pgadmin.utils.ajax import make_json_response, bad_request, \
     success_return, internal_server_error, unauthorized
 from pgadmin.utils.driver import get_driver
 from pgadmin.utils.menu import MenuItem
-from pgadmin.utils.exception import ConnectionLost
+from pgadmin.utils.exception import ConnectionLost, SSHTunnelConnectionLost
 from pgadmin.utils.sqlautocomplete.autocomplete import SQLAutoComplete
 from pgadmin.tools.sqleditor.utils.query_tool_preferences import \
     RegisterQueryToolPreferences
@@ -50,6 +51,11 @@ try:
 except ImportError:
     from urllib.parse import unquote
 
+if sys.version_info[0:2] <= (2, 7):
+    IS_PY2 = True
+else:
+    IS_PY2 = False
+
 
 class SqlEditorModule(PgAdminModule):
     """
@@ -166,7 +172,7 @@ def check_transaction_status(trans_id):
             use_binary_placeholder=True,
             array_to_string=True
         )
-    except ConnectionLost as e:
+    except (ConnectionLost, SSHTunnelConnectionLost) as e:
         raise
     except Exception as e:
         current_app.logger.error(e)
@@ -212,7 +218,7 @@ def start_view_data(trans_id):
         manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(
             trans_obj.sid)
         default_conn = manager.connection(did=trans_obj.did)
-    except ConnectionLost as e:
+    except (ConnectionLost, SSHTunnelConnectionLost) as e:
         raise
     except Exception as e:
         current_app.logger.error(e)
@@ -261,7 +267,7 @@ def start_view_data(trans_id):
         # Execute sql asynchronously
         try:
             status, result = conn.execute_async(sql)
-        except ConnectionLost as e:
+        except (ConnectionLost, SSHTunnelConnectionLost) as e:
             raise
     else:
         status = False
@@ -301,7 +307,7 @@ def start_query_tool(trans_id):
 
     connect = 'connect' in request.args and request.args['connect'] == '1'
 
-    return StartRunningQuery(blueprint, current_app).execute(
+    return StartRunningQuery(blueprint, current_app.logger).execute(
         sql, trans_id, session, connect
     )
 
@@ -310,8 +316,10 @@ def extract_sql_from_network_parameters(request_data, request_arguments,
                                         request_form_data):
     if request_data:
         sql_parameters = json.loads(request_data, encoding='utf-8')
-        if type(sql_parameters) is str:
-            return dict(sql=sql_parameters, explain_plan=None)
+
+        if (IS_PY2 and type(sql_parameters) is unicode) \
+                or type(sql_parameters) is str:
+            return dict(sql=str(sql_parameters), explain_plan=None)
         return sql_parameters
     else:
         return request_arguments or request_form_data
@@ -543,10 +551,12 @@ def poll(trans_id):
     # There may be additional messages even if result is present
     # eg: Function can provide result as well as RAISE messages
     additional_messages = None
+    notifies = None
     if status == 'Success':
         messages = conn.messages()
         if messages:
             additional_messages = ''.join(messages)
+        notifies = conn.get_notifies()
 
     # Procedure/Function output may comes in the form of Notices from the
     # database server, so we need to append those outputs with the
@@ -564,6 +574,7 @@ def poll(trans_id):
             'rows_fetched_from': rows_fetched_from,
             'rows_fetched_to': rows_fetched_to,
             'additional_messages': additional_messages,
+            'notifies': notifies,
             'has_more_rows': has_more_rows,
             'colinfo': columns_info,
             'primary_keys': primary_keys,
@@ -571,7 +582,8 @@ def poll(trans_id):
             'client_primary_key': client_primary_key,
             'has_oids': has_oids,
             'oids': oids
-        }
+        },
+        encoding=conn.python_encoding
     )
 
 
@@ -643,7 +655,8 @@ def fetch(trans_id, fetch_all=None):
             'has_more_rows': has_more_rows,
             'rows_fetched_from': rows_fetched_from,
             'rows_fetched_to': rows_fetched_to
-        }
+        },
+        encoding=conn.python_encoding
     )
 
 
@@ -1378,7 +1391,7 @@ def start_query_download_tool(trans_id):
                     did=trans_obj.did,
                     conn_id=conn_id,
                     auto_reconnect=False,
-                    async=False
+                    async_=False
                 )
 
                 sync_conn.connect(autocommit=False)
@@ -1476,14 +1489,25 @@ def query_tool_status(trans_id):
 
     if conn and trans_obj and session_obj:
         status = conn.transaction_status()
-        return make_json_response(
-            data={
-                'status': status,
-                'message': gettext(
-                    CONNECTION_STATUS_MESSAGE_MAPPING.get(status)
-                )
-            }
-        )
+
+        if status is not None:
+            # Check for the asynchronous notifies statements.
+            conn.check_notifies(True)
+            notifies = conn.get_notifies()
+
+            return make_json_response(
+                data={
+                    'status': status,
+                    'message': gettext(
+                        CONNECTION_STATUS_MESSAGE_MAPPING.get(status),
+                    ),
+                    'notifies': notifies
+                }
+            )
+        else:
+            return internal_server_error(
+                errormsg=gettext("Transaction status check failed.")
+            )
     else:
         return internal_server_error(
             errormsg=gettext("Transaction status check failed.")
@@ -1502,7 +1526,11 @@ def get_filter_data(trans_id):
     Args:
         trans_id: unique transaction id
     """
-    return FilterDialog.get(*check_transaction_status(trans_id))
+
+    status, error_msg, conn, trans_obj, session_ob = \
+        check_transaction_status(trans_id)
+
+    return FilterDialog.get(status, error_msg, conn, trans_obj, session_ob)
 
 
 @blueprint.route(
@@ -1517,8 +1545,12 @@ def set_filter_data(trans_id):
     Args:
         trans_id: unique transaction id
     """
+
+    status, error_msg, conn, trans_obj, session_ob = \
+        check_transaction_status(trans_id)
+
     return FilterDialog.save(
-        *check_transaction_status(trans_id),
+        status, error_msg, conn, trans_obj, session_ob,
         request=request,
         trans_id=trans_id
     )
