@@ -16,9 +16,11 @@ class MenuItem(object):
 
 
 class Panel(object):
-    def __init__(self, name, title, content='', width=500, height=600, isIframe=True,
-                 showTitle=True, isCloseable=True, isPrivate=False, priority=None,
-                 icon=None, data=None, events=None, limit=None, canHide=False):
+    def __init__(
+        self, name, title, content='', width=500, height=600, isIframe=True,
+        showTitle=True, isCloseable=True, isPrivate=False, priority=None,
+        icon=None, data=None, events=None, limit=None, canHide=False
+    ):
         self.name = name
         self.title = title
         self.content = content
